@@ -2,30 +2,9 @@ fregre.basis.cv=function(fdataobj,y,basis.x=NULL,basis.b=NULL,type.basis=NULL,la
 Lfdobj=vec2Lfd(c(0,0),rtt),type.CV=GCV.S,par.CV=list(trim=0),...){
 call<-match.call()
 if (!is.fdata(fdataobj)) fdataobj=fdata(fdataobj)
-nas<-apply(fdataobj$data,1,count.na)
-nas.g<-is.na(y)
-if (is.null(names(y))) names(y)<-1:length(y)
-if (any(nas) & !any(nas.g)) {
-   bb<-!nas
-   cat("Warning: ",sum(nas)," curves with NA are omited\n")
-   fdataobj$data<-fdataobj$data[bb,]
-  y<-y[bb]
-   }
-else {
-if (!any(nas) & any(nas.g)) {
-   cat("Warning: ",sum(nas.g)," values of group with NA are omited \n")
-   bb<-!nas.g
-   fdataobj$data<-fdataobj$data[bb,]
-     y<-y[bb]
-   }
-else {
-if (any(nas) & any(nas.g))  {
-   bb<-!nas & !nas.g
-   cat("Warning: ",sum(!bb)," curves  and values of group with NA are omited \n")
-   fdataobj$data<-fdataobj$data[bb,]
-   y<-y[bb]
-   }
-}}
+        omit <- omit.fdata(fdataobj, y)
+        fdataobj <- omit[[1]]
+        y <- omit[[2]]
 x<-fdataobj[["data"]]
 tt<-fdataobj[["argvals"]]
 rtt<-fdataobj[["rangeval"]]
@@ -39,7 +18,7 @@ if (is.null(basis.x))  {
   nbasis1=seq(max(floor(np/10),11),max(floor(np/5),11),by=2)
   lenbasis.x=length(nbasis1)
   basis.x=list()
-   for (nb.x in 1:lenbasis.x) {
+  for (nb.x in 1:lenbasis.x) {
   if (!is.null(type.basis))  {
     aa1 <- paste("create.", type.basis[1], ".basis", sep = "")
     as <- list()
@@ -66,15 +45,16 @@ if (is.null(basis.b))  {
     names(as)[[1]] <- "rangeval"
     as[[2]] <- nbasis2[nb.x]
     names(as)[[2]] <- "nbasis"
-        basis.b[[nb.x]]=do.call(aa1, as)
+    basis.b[[nb.x]]=do.call(aa1, as)
     }
-   else   basis.b[[nb.x]]=create.bspline.basis(rangeval=rtt,nbasis=nbasis2[nb.x])
-}
-}
+  else   basis.b[[nb.x]]=create.bspline.basis(rangeval=rtt,nbasis=nbasis2[nb.x])
+}  }
 else nbasis2<-basis.b
 lenlambda=length(lambda)
-a1=list()
-a2=list()
+a1=list()  ;a2=list()
+fou<-FALSE
+if (!is.null(type.basis)){
+   if (type.basis=="fourier") fou<-TRUE}
 if (!is.list(basis.x))  {
  lenbasis.x=length(basis.x)
  for (nb.x in 1:lenbasis.x) {
@@ -94,6 +74,7 @@ if (!is.list(basis.x))  {
 else   lenbasis.x=length(nbasis1)
 if (!is.list(basis.b))  {
   lenbasis.y=length(basis.b)
+  maxbasis.y<-which.max(basis.b)
   for (nb.y in 1:lenbasis.y) {
     if (!is.null(type.basis))  {
       if (length(type.basis)>1)       aa1 <- paste("create.", type.basis[2], ".basis", sep = "")
@@ -110,7 +91,6 @@ if (!is.list(basis.b))  {
  basis.b=a2
 }
 else  lenbasis.y=length(nbasis2)
- gcv=array(Inf,dim=c(lenbasis.x,lenbasis.y,lenlambda))
  pr=Inf
  i.lambda.opt=1;i.nb.y.opt=1;i.nb.x.opt=1
  xx<-fdata.cen(fdataobj)
@@ -118,12 +98,46 @@ else  lenbasis.y=length(nbasis2)
  xcen=xx[[1]]
  ymean=mean(y)
  ycen=y-ymean
- for (nb.x in 1:lenbasis.x) {
-	x.fd=Data2fd(argvals=tt,y=t(xcen$data),basisobj=basis.x[[nb.x]])
-  C=t(x.fd$coefs)
-  Cm=t(mean.fd(x.fd)$coefs)
-  for (nb.y in 1:lenbasis.y) {
-   	 J=inprod(basis.x[[nb.x]],basis.b[[nb.y]])
+ if (fou)   	 {
+   basis.x<-basis.b
+   J0=inprod(basis.x[[maxbasis.y]],basis.b[[maxbasis.y]])
+   nb.x<-nb.y
+   nbasis1<-nbasis2
+   warning("Same number of basis elements in the basis.x  and basis.b")
+   lenbasis.x<-lenbasis.y
+         x.fd=Data2fd(argvals=tt,y=t(xcen$data),basisobj=basis.x[[maxbasis.y]])
+         Cfou=t(x.fd$coefs)
+         Cmfou=t(mean.fd(x.fd)$coefs)
+         nbasis12<-basis.x[[maxbasis.y]]$type
+  }
+  else {
+   nbasis12<-rep(NA,lenbasis.x)
+  nbasis22<-rep(NA,lenbasis.y)
+   x.fdfou<-Cfou<-Cmfou<- list()
+   for (nb.x in 1:lenbasis.x) {
+         x.fdfou[[nb.x]]=Data2fd(argvals=tt,y=t(xcen$data),basisobj=basis.x[[nb.x]])
+         Cfou[[nb.x]]=t(x.fdfou[[nb.x]]$coefs)
+         Cmfou[[nb.x]]=matrix(t(mean.fd(x.fdfou[[nb.x]])$coefs))
+         nbasis12[nb.x]<-basis.x[[nb.x]]$type
+         }
+  }
+  gcv=array(NA,dim=c(lenbasis.x,lenbasis.y,lenlambda))
+  for (nb.x in 1:lenbasis.x) {
+   if (fou) {ifou<-nb.x;iifou<-nb.x}
+   else {ifou<-1;iifou<-lenbasis.y  }
+   for (nb.y in ifou:iifou) {
+      if (fou)   	 {
+         nfou=basis.b[[nb.y]]$nbasis
+         J=J0[1:nfou,1:nfou]
+         C<-Cfou[,1:nfou]
+         Cm<-Cmfou[,1:nfou]
+         }
+     else {
+          nbasis22[nb.y]<-basis.b[[nb.y]]$type
+          C<-Cfou[[nb.x]]
+          Cm<-Cmfou[[nb.x]]
+          J<-inprod(basis.x[[nb.x]],basis.b[[nb.y]])
+          }
 	   Z=C%*%J
      Z=cbind(rep(1,len=n),Z)
 	   if (min(lambda)!=0) {
@@ -133,10 +147,11 @@ else  lenbasis.y=length(nbasis2)
      else R=0
      for (k in 1:lenlambda) {
        Sb=t(Z)%*%Z+lambda[k]*R
-       eigchk(Sb)
-       Cinv<-solve(Sb)
-       Sb2=Cinv%*%t(Z)
-       par.CV$S<-Z%*%Sb2
+#      eigchk(Sb)
+#
+      Cinv<-solve(Sb)
+      Sb2=Cinv%*%t(Z)
+      par.CV$S <-Z%*%Sb2
        par.CV$y<-y
        gcv[nb.x,nb.y,k]<- do.call(type.CV,par.CV)
      if (gcv[nb.x,nb.y,k]<pr) {
@@ -151,7 +166,6 @@ else  lenbasis.y=length(nbasis2)
           Cinv.opt=Cinv
      }    }
     }  }
-
     l = which.min(gcv)
     gcv.opt=min(gcv)
     S=Z.opt%*%Sb.opt
@@ -164,9 +178,8 @@ else  lenbasis.y=length(nbasis2)
     #beta.est2=fd(b.est2[-1,1]*diff(rtt),basis.b)
     beta.est=fd(b.est[-1,1],basis.b.opt)
     a.est=b.est[1,1]
-           e=drop(y)-drop(yp)
-       names(e)<-rownames(x)
-
+    e=drop(y)-drop(yp)
+    names(e)<-rownames(x)
     df=basis.b.opt$nbasis+1
     sr2=sum(e^2)/(n-df)
     r2=1-sum(e^2)/sum(ycen^2)
@@ -191,26 +204,20 @@ else  lenbasis.y=length(nbasis2)
     class(object.lm)<-"lm"
 b.est=b.est[-1]
 names(b.est)<-rownames(coefficients)[-1]
-dimnames(gcv)<-list(nbasis1,nbasis2,lambda)
+lambda2<-paste("lambda=",lambda,sep="")
+#if (lenlambda==1)  gcv<-gcv[,,1]
+if (fou)  {
+ nbasis12<-paste(nbasis12,nbasis2,sep="")
+ gcv<-as.matrix(apply(gcv,3,diag))
+ rownames(gcv)<-nbasis12
+ colnames(gcv)<-lambda2
+    }
+else{
+nbasis12<-paste(nbasis12,nbasis1,sep="")
+nbasis22<-paste(nbasis22,nbasis2,sep="")
+dimnames(gcv)<-list(nbasis12,nbasis22,lambda2)
+}
 
-####no es la matriz de hat ya que yp=a.est+S*y y no yp=S*y
-#yp=mean(y)+S%*%ycen
-#b.est=Sb.opt%*%y #idem beta.est$coefs
-#beta.est=fd(b.est*diff(rtt),basis.b.opt)
-#  a.est=ymean-Cm%*%J%*%beta.est$coefs
-#a.est=ymean-Cm.opt%*%J.opt%*%b.est
-#e=y-yp
-#df=sum(diag(S))+1
-#r=x.fd[[2]][[3]]
-#xh=cbind(rep(1,len=nrow(Z.opt)),Z.opt)
-#betah=c(a.est,b.est)
-#colnames(xh)[1]="(Intercept)"
-#vcov2=sr2*solve(t(xh)%*%xh)
-#std.error=sqrt(diag(vcov2))
-#t.value=betah/std.error
-#p.value= 2 * pt(abs(t.value),n-df, lower.tail = FALSE)
-#result<-cbind(betah,std.error,t.value,p.value)
-#colnames(result) <- c("Estimate", "Std. Error", "t value", "Pr(>|t|)")
 out<-list("call"=call,"b.est"=b.est,"a.est"=a.est,"fitted.values"=yp,"H"=S,
 "residuals"=e,"df"=df,"r2"=r2,"sr2"=sr2,"y"=y,"fdataobj"=fdataobj,"gcv"=gcv,
 "lambda.opt"=lambda.opt,"gcv.opt"=gcv.opt,"coefficients"=coefficients,
@@ -220,3 +227,7 @@ class(out)="fregre.fd"
 return(out)
 }
 
+
+
+
+
